---
title: 短代码
weight: 9
prev: /docs/guide/diagrams
next: /docs/guide/shortcodes/callout
---

[Hugo 短代码](https://gohugo.io/content-management/shortcodes/) 是你的内容文件中调用内置或自定义模板的简单片段。

Hextra 提供了一系列美观的短代码以增强你的内容。

{{< cards >}}
  {{< card link="callout" title="注意事项" icon="warning" >}}
  {{< card link="cards" title="卡片" icon="card" >}}
  {{< card link="filetree" title="文件树" icon="folder-tree" >}}
  {{< card link="icon" title="图标" icon="badge-check" >}}
  {{< card link="steps" title="步骤" icon="one" >}}
  {{< card link="tabs" title="标签" icon="collection" >}}
{{< /cards >}}
